from Products.CMFCore.utils import getToolByName
import logging
logger = logging.getLogger("Belimo")


class ImportProfileStep(object):
    """import of GenericSetup profile"""

    def __init__(self, name):
        self.name = name

    def __call__(self, context):
        logger.info("Start importing profile: " + self.name)
        tool = getToolByName(context, 'portal_setup')
        tool.runAllImportStepsFromProfile(self.name)
        logger.info("Stop importing profile: " + self.name)


def common_upgrade(context):
    """ Common upgrade for newer jQuery versions, just to call cookResources.
    """
    tool = getToolByName(context, 'portal_javascripts')
    tool.cookResources()
    logger.info("Cooked the JS Resouces")


step_1_initial_upgrade = ImportProfileStep(
    u'profile-plone.app.jquery:initial-upgrade')

upgrade_2_to_3 = common_upgrade



from setuptools import setup, find_packages

version = '1.8.3'

setup(
    name='plone.app.jquery',
    version=version,
    description="jQuery integration for Plone",
    long_description=open("README.rst").read(),
    classifiers=[
        "Environment :: Web Environment",
        "Framework :: Plone",
        "Framework :: Zope2",
        "License :: OSI Approved :: GNU General Public License (GPL)",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
    ],
    keywords='Plone jQuery',
    author='Plone Foundation',
    author_email='plone-developers@lists.sourceforge.net',
    url='http://pypi.python.org/pypi/plone.app.jquery',
    license='GPL version 2',
    packages=find_packages(exclude=['ez_setup']),
    namespace_packages=['plone', 'plone.app'],
    include_package_data=True,
    zip_safe=False,
    install_requires=[
        'setuptools',
        'Products.CMFCore',
        'Products.GenericSetup',
    ],
    entry_points="""
        [z3c.autoinclude.plugin]
        target = plone
    """,
    extras_require={'test': ['plone.app.testing']},
)
